% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Dr. Jos Ernesto Rayas-Snchez                                 April 10, 2019
% Research Group on Computer-Aided Engineering of Circuits and Systems (CAECAS)
% Department of Electronics, Systems and Informatics                      ITESO
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%               One-Section Impedance Transformer (coarse model)
%
% Usage: Rc = ZTranTL1sec2to1_c(Xc,psic)
%        Xc: row vector for model design parameters (length n).
%        psic: vector of independent variables where Rc should be evaluated.
%        Rc: column vector of model responses at base point Xc.
%
% Model Functions Required: ZtranTL_1sec_c_Matlab.

function Rc = ZTranTL1sec2to1_c(Xc,psic)

% Pre-Assigned Parameters, Xp
Zo = 50;          % Reference impedance (ohms).
ZL = 100;         % Load impedance (ohms).
Z1 = sqrt(Zo*ZL); % Transformer characteristic impedance (ohms).
epsr = 1;         % Effective dielectric constant of the Z-tran.
f0 = 1;           % Reference frequency for wavelength on TL (GHz).
Xp = [Zo ZL Z1 epsr f0];

% Simulator Parameters, Ps
f = psic;
FP = length(f); % Number of frequency points.
IF = f(1);      % Initial frequency (GHz).
FF = f(FP);     % Final frequency (GHz).
Ps = [IF FF FP];

% Calculate Responses
P = [Xp Xc Ps];
[psi,R] = ZtranTL_1sec_c_Matlab(P); 
mS11 = R(:,1);
Rc = mS11;
