% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Dr. Jos Ernesto Rayas-Snchez                                 April 10, 2019
% Research Group on Computer-Aided Engineering of Circuits and Systems (CAECAS)
% Department of Electronics, Systems and Informatics                      ITESO
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                  One-Section Impedance Transformer (fine model)
%
% Usage: [psif,Rf] = ZTranTL1sec2to1_f(Xf)                                       
%        Xf: row vector for model design parameters (length n).
%        psif: column vector of independent variables where Rf was evaluated.
%        Rf: column vector of model responses at base point Xf.
%
% Model Functions Required: ZtranTL_2sec_f_Matlab.

function [psif,Rf] = ZTranTL1sec2to1_f(Xf)

% Pre-Assigned Parameters, Xp
Zo = 50;          % Reference impedance (ohms).
ZL = 100;         % Load impedance (ohms).
Z1 = sqrt(Zo*ZL); % Transformer characteristic impedance (ohms).
epsr = 1;         % Effective dielectric constant of the Z-tran.
f0 = 1;           % Reference frequency for wavelength on TL (GHz).
C1 = 0.5;         % Parasitic capacitors (pF).
C2 = 0.05;
Xp = [Zo ZL Z1 epsr f0 C1 C2];

% Parameters of the Simulator, Ps
IF = 0.2;  % Initial frequency (GHz).
FF = 1.8;  % Final frequency (GHz).
FP = 101;  % Number of frequency points.
Ps = [IF FF FP];

% Calculate Responses
P = [Xp Xf Ps];
[psi,R] = ZtranTL_1sec_f_Matlab(P);
mS11 = R(:,1);
psif = psi;
Rf = mS11;
